@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Class used for testing
-our $VERSION = '3.20210324'; # VERSION
+our $VERSION = '3.20210514'; # VERSION
 use Mail::Milter::Authentication;
 use Mail::Milter::Authentication::Client;
 use Mail::Milter::Authentication::Protocol::Milter;
@@ -419,8 +419,8 @@ sub send_smtp_packet {
         return 1;
     }
     else {
-        chomp $recv;
-        chomp $send;
+        $recv =~ s/\r?\n?$//;
+        $send =~ s/\r?\n?$//;
         warn "SMTP Send expected \"$expect\" received \"$recv\" when sending \"$send\"\n";
         return 0;
     }
@@ -576,7 +576,7 @@ Mail::Milter::Authentication::Tester - Class used for testing
 
 =head1 VERSION
 
-version 3.20210324
+version 3.20210514
 
 =head1 AUTHOR
 
